# pykiwoom
Python Wrapper for Kiwoom Open API+

# Books 

https://wikidocs.net/book/1173


# Examples

## 로그인 

```
from pykiwoom.kiwoom import *

kiwoom = Kiwoom()
kiwoom.CommConnect(block=True)
```
